Conclusion and Future Work
==========================

Conclusion
----------

We accomplished two out of our three main objectives:
developing an accessible website and create a collaborative platform.
However, there are rooms for improvement in the implementation.

Through rigorous :ref:`proc`, we were able to not only maintain
tight collaboration and desirable work quality, but also have better control
over regressions and gain confidence in rolling out new changes,
and improve productivity and performance throughout the three-month period.
We wish to continue ameliorating the process when working on the remaining
tasks of this project as well as in future software development.

The resulted system runs as a web service, allowing clients to run on
any platforms without installation.

Thanks to the simplistic user interface, it is accessible and easy to use.

Future Work
-----------

In the future, we will realize features that have not been implemented:

- Task management
- Jury's role and evaluation
- Notification
- Task discussion
- Statistical reports for academic assistant

On top of that, we need to refine existing features:

- Implement a method that prevents user.
- Add configuration for maximum and minimum grade.
- Check file types for reports and slides.
- Improve user interface and user experience.
